### Set working directory where the Stata files are saved



### Install and load the following packages

library(Amelia)
library(foreign)
library(plm)
library(xtable)
library(lattice)
library(latticeExtra)



### Insert the main datasets

spend <- read.dta("Spending.dta")
turnout <- read.dta("Turnout.dta")

spend <- plm.data(spend, index=c("cowcode","year"))
turnout <- plm.data(turnout, index=c("cowcode","t"))



### Correlation matrix of main independent variables

cormat <- cor(turnout[,c("logfdiflow", "logfdistock", "logportequ", "logtrade")], use="complete")
xtable(cormat)



### Plot of turnout, globalization and total government spending over time

subsetturnout <- subset(turnout, cowcode==900|cowcode==305|cowcode==211|cowcode==20|cowcode==390|cowcode==375|cowcode==220|cowcode==260|cowcode==350
  |cowcode==395|cowcode==205|cowcode==325|cowcode==740|cowcode==212|cowcode==210|cowcode==920|cowcode==385|cowcode==235|cowcode==230|cowcode==380
  |cowcode==225|cowcode==200|cowcode==2 & year>=1970)
subsetturnout <- subsetturnout[nrow(subsetturnout):1,] 

pdf("fig1.pdf")
plot1 <- xyplot(turnout ~ year | country, data=subset(subsetturnout, t!="NA"), xlim=c(1970,2010), col=c("black"), 
  pch=19, xlab="Year", ylab="Turnout", cex=.3)
plot2 <- xyplot(econglob + govspend ~ year | country, data=subsetturnout, xlim=c(1970,2010), col=c("grey","blue"), pch=c(17,15), xlab="", ylab="Globalization
  and spending", cex=.3)
doubleYScale(plot1, plot2, text=c("Turnout, % (left axis)", "KOF Economic globalization scale (right axis)", "Total government spending, % GDP (right axis)"),
  col=c("black","grey","blue"), use.style=F)
update(trellis.last.object(), par.settings=simpleTheme(col = c("black", "black")))
dev.off()



### Scatter plots of countries: spending

pdf("figA1.pdf")
xyplot(socben ~ year | country, data=subset(subsetturnout, country!="Greece" & country!="Iceland"), xlim=c(1970,2010), col=c("black"), 
  pch=19, xlab="Year", ylab="Social spending, %GDP", cex=.3)
dev.off()



### Imputing spending data

spendmi <- read.dta("Spending for imputation.dta")
spendmi <- as.data.frame(spendmi)

set.seed(12345)
spendmi <- amelia(spendmi, m=10, ts="year", cs="cowcode", noms="pr", lags=c("unionlevel","autotrans",
  "logfdiflow","logportequ","logfdistock","govspend","socben","deficit","unexpgrowthpc","autocons"), 
  leads=c("unionlevel","autotrans","logfdiflow","logportequ","logfdistock","govspend","socben","deficit",
  "unexpgrowthpc","autocons"))
write.amelia(obj=spendmi, file.stem = "spendmi", format = "dta")
save(spendmi, file="spendmi.RData")