* Using Stata MP 12.1

* Set working directory
cd "C:\Users\John\Dropbox\Globalization and Turnout\Replication Materials"
use "Turnout.dta", clear

* Install estout and xtserial if not already installed





*************************************** IMPORTANT THINGS USED THROUGHOUT ****************************************

xtset cowcode t



*** Abbreviations
global glob "logfdistock logfdiflow logportequ factor logtrade"
global controls "logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness"
global controlsminusmixed "logreg vap3069 timesince nopres cvfranklin pr disrel enps closeness"
global trends "syear2-syearsq920"
global trendsminuslux "syear2-syear211 syear220-syearsq210 syearsq220-syearsq920"



*** Create ownership scale using factor analysis conditional on country effects
xi: factor logfdistock logfdiflow logportequ i.cowcode, ipf
predict factor, b





*************************************** DESCRIPTIVE ANALYSIS AND DIAGNOSTICS *******************************************

*** Pairwise correlation of economic globalization variables
pwcorr logfdiflow logfdistock logportequ logtrade, obs star(5)



*** Baseline model
quietly xtreg turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness syear2-syearsq920, re
predict predspec



*** Test for heteroskedasticity: with all permutations of country FE and country-specific time trends
quietly xtgls turnout $controls if predspec!=., igls panels(heteroskedastic)
quietly estimates store hetero
quietly xtgls turnout $controls if predspec!=.
quietly local df = e(N_g) - 1
lrtest hetero . , df(`df')

quietly xtgls turnout $controls i.cowcode if predspec!=., igls panels(heteroskedastic)
quietly estimates store hetero
quietly xtgls turnout $controls i.cowcode if predspec!=.
quietly local df = e(N_g) - 1
lrtest hetero . , df(`df')

quietly xtgls turnout $controls $trends if predspec!=., igls panels(heteroskedastic)
quietly estimates store hetero
quietly xtgls turnout $controls $trends if predspec!=.
quietly local df = e(N_g) - 1
lrtest hetero . , df(`df')

quietly xtgls turnout $controls i.cowcode $trends if predspec!=., igls panels(heteroskedastic)
quietly estimates store hetero
quietly xtgls turnout $controls i.cowcode $trends if predspec!=.
quietly local df = e(N_g) - 1
lrtest hetero . , df(`df')



*** Test for first-order serial correlation
xtserial turnout $controls if predspec!=.
xi: xtserial turnout $controls i.cowcode if predspec!=.
xtserial turnout $controls $trends if predspec!=.
xi: xtserial turnout $controls i.cowcode $trends if predspec!=.



*** Hausman test of random v. fixed effects
quietly xtreg turnout $controls $trends if predspec!=., fe
quietly estimates store fixed
quietly xtreg turnout $controls $trends if predspec!=., re
hausman fixed ., sigmamore

quietly xtreg turnout govspend polity ps semipres volreg fed bicam vap3069 closeness disrel enps cvfranklin mixed pr timesince logreg nopres syear2-syearsq920 if predspec!=., fe
quietly estimates store fixed
quietly xtreg turnout govspend polity ps semipres volreg fed bicam vap3069 closeness disrel enps cvfranklin mixed pr timesince logreg nopres syear2-syearsq920 if predspec!=., re
hausman fixed ., sigmamore



*** Identify the risk of spurious correlation by examining the hypothesis that all panels are stationary (only Fisher test allows for unbalanced panels with missing data)
xtunitroot fisher turnout if predspec!=., pp lag(1) demean

	

*** Descriptive statistics based on the data used in the baseline model analysis
eststo clear
quietly eststo: xtabond turnout $controls $trends, lag(1) vce(robust) artests(4)
preserve
drop if _est_est1==0
summarize turnout $controls $glob govspend logfdistockasset logfdistockliab logfdiin logfdiout logportequasset logportequliab logimports logexports logeafdiflow logeafdistock logeaportequ logeatrade econglob actflows restrictions kaopen turnoutvap logvap uniondensity popden u deficit growthpc cpi loggdppc deindust socben wcoord gininet polity vage govparty
restore







************************************************* TABLE 2 *******************************************

eststo clear

****** Baseline model
xtabond turnout $controls $trends, artests(4) vce(robust) lag(1)
estat abond

* ...requires correction for AR2 violation - so use third lags as GMM instruments

eststo: xtdpd turnout L1.turnout $controls $trends, dgmmiv(turnout, lagrange(3)) div($controls $trends) vce(robust) artests(4)
quietly sort cowcode t
quietly predict pred
quietly xtdpd turnout L1.turnout $controls $trends, dgmmiv(turnout, lagrange(3)) div($controls $trends) artests(4)
estat sargan



****** Direct globalization models
foreach x of varlist logfdistock logportequ logtrade {
  xtabond turnout `x' $controls $trends, artests(4) vce(robust) lag(1)
  estat abond
  quietly xtabond turnout `x' $controls $trends, artests(4) lag(1)
  estat sargan
}

* ...FDI stock fails Sargan test so use a maximum of 9 lags as GMM instruments

eststo: xtabond turnout logfdistock $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly sort cowcode t
quietly predict predlogfdistock
estat abond
quietly xtabond turnout logfdistock $controls $trends, artests(4) lag(1) maxldep(9)
estat sargan

* ...FDI flows data unavailable for Luxembourg and very limited for Belgium, so need different trend included (see above); also fails AR2 test so use third lags as GMM instruments

eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendsminuslux) vce(robust) artests(4)
quietly sort cowcode t
quietly predict predlogfdiflow
estat abond
quietly xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendsminuslux) artests(4)
estat sargan

* ...no problems for portfolio equity stocks

eststo: xtabond turnout logportequ $controls $trends, artests(4) vce(robust) lag(1)
quietly sort cowcode t
quietly predict predlogportequ
quietly xtabond turnout logportequ $controls $trends, artests(4) lag(1)
estat sargan

* ...same missing data (no Belgium of Luxembourg) problems for factor variable as FDI flows

eststo: xtabond turnout factor $controls $trendsminuslux, artests(4) vce(robust) lag(1)
quietly sort cowcode t
quietly predict predfactor
estat abond
quietly xtabond turnout factor $controls $trendsminuslux, artests(4) lag(1)
estat sargan

* ...trade fails AR2 test so use third lags as GMM instruments

eststo: xtdpd turnout L1.turnout logtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends) vce(robust) artests(4)
quietly sort cowcode t
quietly predict predlogtrade
estat abond
quietly xtdpd turnout L1.turnout logtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends) artests(4)
estat sargan


  
****** Adding spending as a mediator (both models suffer from AR2 violation, so use third lags as GMM instruments)
eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendsminuslux) artests(4) vce(robust)
sort cowcode t
predict predintlogfdiflow
estat abond
quietly xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendsminuslux) artests(4)
estat sargan

eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends) artests(4) vce(robust)
sort cowcode t
predict predintlogportequ
estat abond
quietly xtdpd turnout L1.turnout logportequ govspend $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends) artests(4)
estat sargan



****** Adding trade as a mediator (both models suffer from AR2 violation, so use third lags as GMM instruments)
eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendsminuslux) artests(4) vce(robust)
sort cowcode t
predict predinttradelogfdiflow
estat abond
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendsminuslux) artests(4)
estat sargan

eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends) artests(4) vce(robust)
sort cowcode t
predict predinttradelogportequ
estat abond
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends) artests(4)
estat sargan



****** Table of results
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")

* ...estimating model fit with a within-R2 approximtion
pwcorr D1.turnout D1.pred D1.predlogfdistock D1.predlogfdiflow D1.predlogportequ D1.predfactor D1.predlogtrade D1.predintlogfdiflow D1.predintlogportequ D1.predinttradelogfdiflow D1.predinttradelogportequ

* Note: need to subtract no. countries from each xtdpd model (as counts observations in levels equation), and change FDI flows to 22 countries (Lux drops out after differencing)

drop _est_est1 - predinttradelogportequ









************************************************* TABLE 4 *******************************************

eststo clear

foreach x of varlist logfdiin logfdiout {
  eststo: quietly xtabond turnout `x' $controls $trendsminuslux, artests(4) vce(robust) lag(1)
}
eststo: quietly xtabond turnout logfdiin logfdiout $controlsminusmixed $trendsminuslux, artests(4) vce(robust) lag(1)
test logfdiin=logfdiout

foreach x of varlist logfdistockasset logfdistockliab {
  eststo: quietly xtabond turnout `x' $controls $trends, artests(4) vce(robust) lag(1)
}
eststo: quietly xtabond turnout logfdistockasset logfdistockliab $controls $trends, artests(4) vce(robust) lag(1)
test logfdistockasset=logfdistockliab

estout, cells(b(star fmt(3)) se(par)) stats(N N_g, fmt(0 0)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(logfdiout logfdiin logfdistockasset logfdistockliab) order(logfdiin logfdiout logfdistockasset logfdistockliab)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g, fmt(0) labels("Observations" "Countries")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(logfdiout logfdiin logfdistockasset logfdistockliab) order(logfdiin logfdiout logfdistockasset logfdistockliab) varlabels(logfdiout "FDI flows, in (log)" logfdiin "FDI flows, in (log)" logfdistockasset "FDI stock, assets (log)" logfdistockliab "FDI stock, liabilities (log)")

eststo clear

foreach x of varlist logportequasset logportequliab {
  eststo: quietly xtabond turnout `x' $controls $trends, artests(4) vce(robust) lag(1)
}
eststo: quietly xtabond turnout logportequasset logportequliab $controls $trends, artests(4) vce(robust) lag(1)
test logportequasset=logportequliab

foreach x of varlist logimports logexports {
  eststo: quietly xtabond turnout `x' $controls $trends, artests(4) vce(robust) lag(1)
}
eststo: quietly xtabond turnout logimports logexports $controls $trends, artests(4) vce(robust) lag(1)
test logimports=logexports

estout, cells(b(star fmt(3)) se(par)) stats(N N_g, fmt(0 0)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(logportequasset logportequliab logimports logexports) order(logportequasset logportequliab logimports logexports)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g, fmt(0) labels("Observations" "Countries")) mlabels("Model (7)" "Model (8)" "Model (9)" "Model (10)" "Model (11)" "Model (12)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(logportequasset logportequliab logimports logexports) order(logportequasset logportequliab logimports logexports) varlabels(logportequasset "Portfolio stocks, assets (log)" logportequliab "Portfolio stocks, liabilities (log)" logimports "Imports (log)" logexports "Exports (log)")






************************************************* ROBUSTNESS CHECKS *******************************************

*** Checking sensitivity to removing each country from the regression models
eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 212 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtdpd turnout L1.turnout $controls $trends if cowcode!=`c', dgmmiv(turnout, lagrange(3)) div($controls $trends) vce(robust) artests(4)
}
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $controls) order(L.turnout $controls) varlabels(_cons Constant)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 212 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtabond turnout logfdistock $controls $trends if cowcode!=`c', vce(robust) artests(4) lag(1) maxldep(9)
}
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(logfdistock) order(logfdistock)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if cowcode!=`c', dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendsminuslux) vce(robust) artests(4)
}
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(logfdiflow) order(logfdiflow)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 212 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtabond turnout logportequ $controls $trends if cowcode!=`c', vce(robust) artests(4) lag(1)
}
estout, keep(logportequ) order(logportequ) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtabond turnout factor $controls $trendsminuslux if cowcode!=`c', artests(4) vce(robust) lag(1)
}
estout, keep(factor) order(factor) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 212 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtdpd turnout L1.turnout logtrade $controls $trends if cowcode!=`c', dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends) vce(robust) artests(4)
}
estout, keep(logtrade) order(logtrade) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 212 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if cowcode!=`c', dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendsminuslux) artests(4) vce(robust)
}
estout, keep(logfdiflow govspend) order(logfdiflow govspend) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 212 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends if cowcode!=`c', dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends) artests(4) vce(robust)
}
estout, keep(logportequ govspend) order(logportequ govspend) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 212 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if cowcode!=`c', dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendsminuslux) artests(4) vce(robust)
}
estout, keep(logfdiflow logtrade govspend) order(logfdiflow logtrade govspend) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01)

eststo clear
quietly foreach c of numlist 2 20 200 205 210 211 212 220 225 230 235 260 305 325 350 375 380 385 390 395 740 900 920 { 
  eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if cowcode!=`c', dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends) artests(4) vce(robust)
}
estout, keep(logportequ logtrade govspend) order(logportequ logtrade govspend) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) legend starlevels(* 0.10 ** 0.05 *** 0.01)



*** Removing US mid-term elections
global controlsnomt "logreg vap3069 timesince cvfranklin mixed pr disrel enps closeness"
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controlsnomt $trends if nopres==0, dgmmiv(turnout, lagrange(3)) div($controlsnomt $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout $controlsnomt $trends if nopres==0, dgmmiv(turnout, lagrange(3)) div($controlsnomt $trends) artests(4)
estat sargan
quietly eststo: xtabond turnout logfdistock $controlsnomt $trends if nopres==0, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout logfdistock $controlsnomt $trends if nopres==0, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controlsnomt $trendsminuslux if nopres==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controlsnomt $trendsminuslux) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logfdiflow $controlsnomt $trendsminuslux if nopres==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controlsnomt $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtabond turnout logportequ $controlsnomt $trends if nopres==0, artests(4) vce(robust) lag(1)
quietly xtabond turnout logportequ $controlsnomt $trends if nopres==0, artests(4) lag(1)
estat sargan
quietly eststo: xtabond turnout factor $controlsnomt $trendsminuslux if nopres==0, artests(4) vce(robust) lag(1)
quietly xtabond turnout factor $controlsnomt $trendsminuslux if nopres==0, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logtrade $controlsnomt $trends if nopres==0, dgmmiv(turnout, lagrange(3)) div(logtrade $controlsnomt $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logtrade $controlsnomt $trends if nopres==0, dgmmiv(turnout, lagrange(3)) div(logtrade $controlsnomt $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controlsnomt $trendsminuslux if nopres==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controlsnomt $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend $controlsnomt $trendsminuslux if nopres==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controlsnomt $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controlsnomt $trends if nopres==0, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controlsnomt $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend $controlsnomt $trends if nopres==0, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controlsnomt $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controlsnomt $trendsminuslux if nopres==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controlsnomt $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controlsnomt $trendsminuslux if nopres==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controlsnomt $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controlsnomt $trends if nopres==0, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controlsnomt $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controlsnomt $trends if nopres==0, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controlsnomt $trends) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controlsnomt) order(L.turnout $controlsnomt logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controlsnomt) order(L.turnout $controlsnomt logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Removing tax havens (Iceland, Ireland, Luxembourg, Switzerland) from the analysis
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div($controls $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div($controls $trends) artests(4)
estat sargan
quietly eststo: xtabond turnout logfdistock $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout logfdistock $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendsminuslux) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtabond turnout logportequ $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", artests(4) vce(robust) lag(1)
quietly xtabond turnout logportequ $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", artests(4) lag(1)
estat sargan
quietly eststo: xtabond turnout factor $controls $trendsminuslux if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", artests(4) vce(robust) lag(1)
quietly xtabond turnout factor $controls $trendsminuslux if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logtrade $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade logtrade $controls $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if country!="Iceland" & country!="Ireland" & country!="Luxembourg" & country!="Switzerland", dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Remove countries with compulsory voting
global controlsnocv "logreg vap3069 timesince nopres mixed pr disrel enps closeness"
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controlsnocv $trends, dgmmiv(turnout, lagrange(3)) div($controlsnocv $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout $controlsnocv $trends, dgmmiv(turnout, lagrange(3)) div($controlsnocv $trends) artests(4)
estat sargan
quietly eststo: xtabond turnout logfdistock $controlsnocv $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout logfdistock $controlsnocv $trends, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controlsnocv $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controlsnocv $trendsminuslux) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logfdiflow $controlsnocv $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controlsnocv $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtabond turnout logportequ $controlsnocv $trends, artests(4) vce(robust) lag(1)
quietly xtabond turnout logportequ $controlsnocv $trends, artests(4) lag(1)
estat sargan
quietly eststo: xtabond turnout factor $controlsnocv $trendsminuslux, artests(4) vce(robust) lag(1)
quietly xtabond turnout factor $controlsnocv $trendsminuslux, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logtrade $controlsnocv $trends, dgmmiv(turnout, lagrange(3)) div(logtrade $controlsnocv $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logtrade $controlsnocv $trends, dgmmiv(turnout, lagrange(3)) div(logtrade $controlsnocv $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controlsnocv $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controlsnocv $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend $controlsnocv $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controlsnocv $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controlsnocv $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controlsnocv $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend $controlsnocv $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controlsnocv $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controlsnocv $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controlsnocv $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controlsnocv $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controlsnocv $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controlsnocv $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controlsnocv $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controlsnocv $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controlsnocv $trends) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controlsnocv) order(L.turnout $controlsnocv logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controlsnocv) order(L.turnout $controlsnocv logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Turnout as %VAP as depedent variable
global controlsvap "logvap vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness"
eststo clear
quietly eststo: xtdpd turnoutvap L1.turnoutvap $controlsvap $trends, dgmmiv(turnoutvap, lagrange(3)) div($controlsvap $trends) vce(robust) artests(4)
quietly xtdpd turnoutvap L1.turnoutvap $controlsvap $trends, dgmmiv(turnoutvap, lagrange(3)) div($controlsvap $trends) artests(4)
estat sargan
quietly eststo: xtabond turnoutvap logfdistock $controlsvap $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnoutvap logfdistock $controlsvap $trends, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnoutvap L1.turnoutvap logfdiflow $controlsvap $trendsminuslux, dgmmiv(turnoutvap, lagrange(3)) div(logfdiflow $controlsvap $trendsminuslux) vce(robust) artests(4)
quietly xtdpd turnoutvap L1.turnoutvap logfdiflow $controlsvap $trendsminuslux, dgmmiv(turnoutvap, lagrange(3)) div(logfdiflow $controlsvap $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtabond turnoutvap logportequ $controlsvap $trends, artests(4) vce(robust) lag(1)
quietly xtabond turnoutvap logportequ $controlsvap $trends, artests(4) lag(1)
estat sargan
quietly eststo: xtabond turnoutvap factor $controlsvap $trendsminuslux, artests(4) vce(robust) lag(1)
quietly xtabond turnoutvap factor $controlsvap $trendsminuslux, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnoutvap L1.turnoutvap logtrade $controlsvap $trends, dgmmiv(turnoutvap, lagrange(3)) div(logtrade $controlsvap $trends) vce(robust) artests(4)
quietly xtdpd turnoutvap L1.turnoutvap logtrade $controlsvap $trends, dgmmiv(turnoutvap, lagrange(3)) div(logtrade $controlsvap $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnoutvap L1.turnoutvap logfdiflow govspend $controlsvap $trendsminuslux, dgmmiv(turnoutvap, lagrange(3)) div(logfdiflow govspend $controlsvap $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnoutvap L1.turnoutvap logfdiflow govspend $controlsvap $trendsminuslux, dgmmiv(turnoutvap, lagrange(3)) div(logfdiflow govspend $controlsvap $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnoutvap L1.turnoutvap logportequ govspend $controlsvap $trends, dgmmiv(turnoutvap, lagrange(3)) div(logportequ govspend $controlsvap $trends) artests(4) vce(robust)
quietly xtdpd turnoutvap L1.turnoutvap logportequ govspend $controlsvap $trends, dgmmiv(turnoutvap, lagrange(3)) div(logportequ govspend $controlsvap $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnoutvap L1.turnoutvap logfdiflow govspend logtrade $controlsvap $trendsminuslux, dgmmiv(turnoutvap, lagrange(3)) div(logfdiflow govspend logtrade $controlsvap $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnoutvap L1.turnoutvap logfdiflow govspend logtrade $controlsvap $trendsminuslux, dgmmiv(turnoutvap, lagrange(3)) div(logfdiflow govspend logtrade $controlsvap $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnoutvap L1.turnoutvap logportequ govspend logtrade $controlsvap $trends, dgmmiv(turnoutvap, lagrange(3)) div(logportequ govspend logtrade $controlsvap $trends) artests(4) vce(robust)
quietly xtdpd turnoutvap L1.turnoutvap logportequ govspend logtrade $controlsvap $trends, dgmmiv(turnoutvap, lagrange(3)) div(logportequ govspend logtrade $controlsvap $trends) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnoutvap $glob govspend $controlsvap) order(L.turnoutvap $controlsvap logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnoutvap $glob govspend $controlsvap) order(L.turnoutvap $controlsvap logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnoutvap "LDV" logvap "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Removing outliers (observations with standardized residuals with absolute value >2)
eststo clear
quietly xtdpd turnout L1.turnout $controls $trends, dgmmiv(turnout, lagrange(3)) div($controls $trends) vce(robust) artests(4)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtdpd turnout L1.turnout $controls $trends if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div($controls $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout $controls $trends if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div($controls $trends) artests(4)
estat sargan
quietly drop res stdres
quietly xtabond turnout logfdistock $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtabond turnout logfdistock $controls $trends if abs(stdres)<=2, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout logfdistock $controls $trends if abs(stdres)<=2, artests(4) lag(1) maxldep(9)
estat sargan
quietly drop res stdres
quietly xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendsminuslux) vce(robust) artests(4)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendsminuslux) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendsminuslux) artests(4)
estat sargan
quietly drop res stdres
quietly xtabond turnout logportequ $controls $trends, artests(4) vce(robust) lag(1)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtabond turnout logportequ $controls $trends if abs(stdres)<=2, artests(4) vce(robust) lag(1)
quietly xtabond turnout logportequ $controls $trends if abs(stdres)<=2, artests(4) lag(1)
estat sargan
quietly drop res stdres
quietly xtabond turnout factor $controls $trendsminuslux, artests(4) vce(robust) lag(1)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtabond turnout factor $controls $trendsminuslux if abs(stdres)<=2, artests(4) vce(robust) lag(1)
quietly xtabond turnout factor $controls $trendsminuslux if abs(stdres)<=2, artests(4) lag(1)
estat sargan
quietly drop res stdres
quietly xtdpd turnout L1.turnout logtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends) vce(robust) artests(4)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $trends if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logtrade $controls $trends if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends) artests(4)
estat sargan
quietly drop res stdres
quietly xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendsminuslux) artests(4) vce(robust)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendsminuslux) artests(4)
estat sargan
quietly drop res stdres
quietly xtdpd turnout L1.turnout logportequ govspend $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends) artests(4) vce(robust)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend $controls $trends if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends) artests(4)
estat sargan
quietly drop res stdres
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendsminuslux) artests(4) vce(robust)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendsminuslux) artests(4)
estat sargan
quietly drop res stdres
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends) artests(4) vce(robust)
quietly sort cowcode t
quietly predict res, e
quietly egen stdres=std(res)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if abs(stdres)<=2, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends) artests(4)
estat sargan
quietly drop res stdres
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Inclusion of additional controls (see list in for loop)
foreach var of varlist eudummy cumeueffectfranklin uniondensity popden u deficit growthpc cpi loggdppc deindust socben wcoord ginigross gininet polity vage govparty {
  quietly eststo clear
  quietly eststo: xtdpd turnout L1.turnout `var' $controls $trends, dgmmiv(turnout, lagrange(3)) div(`var' $controls $trends) vce(robust) artests(4)
  quietly eststo: xtabond turnout logfdistock `var' $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
  quietly eststo: xtdpd turnout L1.turnout logfdiflow `var' $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow `var' $controls $trendsminuslux) vce(robust) artests(4)
  quietly eststo: xtabond turnout logportequ `var' $controls $trends, artests(4) vce(robust) lag(1)
  quietly eststo: xtabond turnout factor `var' $controls $trendsminuslux, artests(4) vce(robust) lag(1)
  quietly eststo: xtdpd turnout L1.turnout logtrade `var' $controls $trends, dgmmiv(turnout, lagrange(3)) div(logtrade `var' $controls $trends) vce(robust) artests(4)
  quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend `var' $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend `var' $controls $trendsminuslux) artests(4) vce(robust)
  quietly eststo: xtdpd turnout L1.turnout logportequ govspend `var' $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend `var' $controls $trends) artests(4) vce(robust)
  quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade `var' $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade `var' $controls $trendsminuslux) artests(4) vce(robust)
  quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade `var' $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade `var' $controls $trends) artests(4) vce(robust)
  estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
}



*** Only examine countries not in the EU (first 3 globalization models could not be estimated with robust SEs)
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controls $trends if eudummy==0, dgmmiv(turnout, lagrange(3)) div(eudummy $controls $trends) vce(robust) artests(4)
quietly eststo: xtabond turnout logfdistock $controls $trends if eudummy==0, artests(4) lag(1) maxldep(9)
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if eudummy==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow eudummy $controls $trendsminuslux) artests(4)
quietly eststo: xtabond turnout logportequ $controls $trends if eudummy==0, lag(1)
quietly eststo: xtabond turnout factor $controls $trendsminuslux if eudummy==0, artests(4) vce(robust) lag(1)
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $trends if eudummy==0, dgmmiv(turnout, lagrange(3)) div(logtrade eudummy $controls $trends) vce(robust) artests(4)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if eudummy==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend eudummy $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends if eudummy==0, dgmmiv(turnout, lagrange(3)) div(logportequ govspend eudummy $controls $trends) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if eudummy==0, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade eudummy $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if eudummy==0, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade eudummy $controls $trends) artests(4) vce(robust)
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Only examine countries in the EU (models 2 and 4 could not be estimated with robust SEs)
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controls $trends if eudummy==1, dgmmiv(turnout, lagrange(3)) div(eudummy $controls $trends) vce(robust) artests(4)
quietly eststo: xtabond turnout logfdistock $controls $trends if eudummy==1, artests(4) lag(1) maxldep(9)
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if eudummy==1, dgmmiv(turnout, lagrange(3)) div(logfdiflow eudummy $controls $trendsminuslux) vce(robust) artests(4)
quietly eststo: xtabond turnout logportequ $controls $trends if eudummy==1, lag(1)
quietly eststo: xtabond turnout factor $controls $trendsminuslux if eudummy==1, artests(4) vce(robust) lag(1)
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $trends if eudummy==1, dgmmiv(turnout, lagrange(3)) div(logtrade eudummy $controls $trends) vce(robust) artests(4)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if eudummy==1, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend eudummy $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends if eudummy==1, dgmmiv(turnout, lagrange(3)) div(logportequ govspend eudummy $controls $trends) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if eudummy==1, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade eudummy $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if eudummy==1, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade eudummy $controls $trends) artests(4) vce(robust)
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Only examine countries that subsequently entered the Eurozone
g eurozone = 0
replace eurozone = 1 if country=="Austria" | country=="Belgium" | country=="Finland" | country=="France" | country=="Germany" | country=="Greece" | country=="Ireland" | country=="Italy" | country=="Luxembourg" | country=="Malta" | country=="Netherlands" | country=="Portugal" | country=="Spain"

eststo clear
quietly eststo: xtdpd turnout L1.turnout $controls $trends if eurozone==1, dgmmiv(turnout, lagrange(3)) div(eurozone $controls $trends) vce(robust) artests(4)
quietly eststo: xtabond turnout logfdistock $controls $trends if eurozone==1, artests(4) lag(1) maxldep(9)
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if eurozone==1, dgmmiv(turnout, lagrange(3)) div(logfdiflow eurozone $controls $trendsminuslux) vce(robust) artests(4)
quietly eststo: xtabond turnout logportequ $controls $trends if eurozone==1, lag(1)
quietly eststo: xtabond turnout factor $controls $trendsminuslux if eurozone==1, artests(4) vce(robust) lag(1)
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $trends if eurozone==1, dgmmiv(turnout, lagrange(3)) div(logtrade eurozone $controls $trends) vce(robust) artests(4)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if eurozone==1, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend eurozone $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends if eurozone==1, dgmmiv(turnout, lagrange(3)) div(logportequ govspend eurozone $controls $trends) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if eurozone==1, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade eurozone $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if eurozone==1, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade eurozone $controls $trends) artests(4) vce(robust)
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Only examine countries that subsequently entered the Eurozone --- after 1979 (start of EMS/ERM)
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controls $trends if eurozone==1 & year>=1979, dgmmiv(turnout, lagrange(3)) div(eurozone $controls $trends) vce(robust) artests(4)
quietly eststo: xtabond turnout logfdistock $controls $trends if eurozone==1 & year>=1979, artests(4) lag(1) maxldep(9)
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendsminuslux if eurozone==1 & year>=1979, dgmmiv(turnout, lagrange(3)) div(logfdiflow eurozone $controls $trendsminuslux) vce(robust) artests(4)
quietly eststo: xtabond turnout logportequ $controls $trends if eurozone==1 & year>=1979, lag(1)
quietly eststo: xtabond turnout factor $controls $trendsminuslux if eurozone==1 & year>=1979, artests(4) vce(robust) lag(1)
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $trends if eurozone==1 & year>=1979, dgmmiv(turnout, lagrange(3)) div(logtrade eurozone $controls $trends) vce(robust) artests(4)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendsminuslux if eurozone==1 & year>=1979, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend eurozone $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends if eurozone==1 & year>=1979, dgmmiv(turnout, lagrange(3)) div(logportequ govspend eurozone $controls $trends) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendsminuslux if eurozone==1 & year>=1979, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade eurozone $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends if eurozone==1 & year>=1979, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade eurozone $controls $trends) artests(4) vce(robust)
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls `var') order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Interact EU membership with globalization variables
foreach x of varlist logfdistock logfdiflow logportequ logtrade factor {
  g `x'_eudummy = `x' * eudummy
}
eststo clear
quietly eststo: xtdpd turnout L1.turnout eudummy $controls $trends, dgmmiv(turnout, lagrange(3)) div(eudummy $controls $trends) vce(robust) artests(4)
quietly eststo: xtabond turnout logfdistock logfdistock_eudummy eudummy $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly eststo: xtdpd turnout L1.turnout logfdiflow logfdiflow_eudummy eudummy $controls $trendsminuslux, vce(robust) dgmmiv(turnout, lagrange(3)) div(logfdiflow logfdiflow_eudummy eudummy $controls $trendsminuslux) artests(4)
quietly eststo: xtabond turnout logportequ logportequ_eudummy eudummy $controls $trends, vce(robust) lag(1)
quietly eststo: xtabond turnout factor factor_eudummy eudummy $controls $trendsminuslux, artests(4) vce(robust) lag(1)
quietly eststo: xtdpd turnout L1.turnout logtrade logtrade_eudummy eudummy $controls $trends, dgmmiv(turnout, lagrange(3)) div(logtrade logtrade_eudummy eudummy $controls $trends) vce(robust) artests(4)
quietly eststo: xtdpd turnout L1.turnout logfdiflow logfdiflow_eudummy eudummy govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow logfdiflow_eudummy govspend eudummy $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ logportequ_eudummy eudummy govspend $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ logportequ_eudummy govspend eudummy $controls $trends) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logfdiflow logfdiflow_eudummy eudummy govspend logtrade $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow logfdiflow_eudummy govspend logtrade eudummy $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logportequ_eudummy eudummy logtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ logportequ_eudummy govspend logtrade eudummy $controls $trends) artests(4) vce(robust)
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls eudummy logfdistock_eudummy logfdiflow_eudummy logportequ_eudummy factor_eudummy logtrade_eudummy) order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade logfdistock_eudummy logfdiflow_eudummy logportequ_eudummy factor_eudummy logtrade_eudummy govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Interact cumulative EU membership (in years) with globalization variables
foreach x of varlist logfdistock logfdiflow logportequ logtrade factor {
  g `x'_cumeueffectfranklin = `x' * cumeueffectfranklin
}
eststo clear
quietly eststo: xtdpd turnout L1.turnout cumeueffectfranklin $controls $trends, dgmmiv(turnout, lagrange(3)) div(cumeueffectfranklin $controls $trends) vce(robust) artests(4)
quietly eststo: xtabond turnout logfdistock logfdistock_cumeueffectfranklin cumeueffectfranklin $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly eststo: xtdpd turnout L1.turnout logfdiflow logfdiflow_cumeueffectfranklin cumeueffectfranklin $controls $trendsminuslux, vce(robust) dgmmiv(turnout, lagrange(3)) div(logfdiflow logfdiflow_cumeueffectfranklin cumeueffectfranklin $controls $trendsminuslux) artests(4)
quietly eststo: xtabond turnout logportequ logportequ_cumeueffectfranklin cumeueffectfranklin $controls $trends, vce(robust) lag(1)
quietly eststo: xtabond turnout factor factor_cumeueffectfranklin cumeueffectfranklin $controls $trendsminuslux, artests(4) vce(robust) lag(1)
quietly eststo: xtdpd turnout L1.turnout logtrade logtrade_cumeueffectfranklin cumeueffectfranklin $controls $trends, dgmmiv(turnout, lagrange(3)) div(logtrade logtrade_cumeueffectfranklin cumeueffectfranklin $controls $trends) vce(robust) artests(4)
quietly eststo: xtdpd turnout L1.turnout logfdiflow logfdiflow_cumeueffectfranklin cumeueffectfranklin govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow logfdiflow_cumeueffectfranklin govspend cumeueffectfranklin $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ logportequ_cumeueffectfranklin cumeueffectfranklin govspend $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ logportequ_cumeueffectfranklin govspend cumeueffectfranklin $controls $trends) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logfdiflow logfdiflow_cumeueffectfranklin cumeueffectfranklin govspend logtrade $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow logfdiflow_cumeueffectfranklin govspend logtrade cumeueffectfranklin $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logportequ_cumeueffectfranklin cumeueffectfranklin logtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ logportequ_cumeueffectfranklin govspend logtrade cumeueffectfranklin $controls $trends) artests(4) vce(robust)
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls cumeueffectfranklin logfdistock_cumeueffectfranklin logfdiflow_cumeueffectfranklin logportequ_cumeueffectfranklin factor_cumeueffectfranklin logtrade_cumeueffectfranklin) order(L.turnout $controls `var' logfdistock logfdiflow logportequ factor logtrade logfdistock_cumeueffectfranklin logfdiflow_cumeueffectfranklin logportequ_cumeueffectfranklin factor_cumeueffectfranklin logtrade_cumeueffectfranklin govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Use decade dummies instead of country-specific time trends
g dummy80s = year>=1980 & year<1990
g dummy90s = year>=1990 & year<2000
g dummy00s = year>=2000
global decades "dummy80s dummy90s dummy00s"
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controls $decades, dgmmiv(turnout, lagrange(3)) div($controls $decades) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout $controls $decades, dgmmiv(turnout, lagrange(3)) div($controls $decades) artests(4)
estat sargan
quietly eststo: xtabond turnout logfdistock $controls $decades, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout logfdistock $controls $decades, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $decades) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logfdiflow $controls $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $decades) artests(4)
estat sargan
quietly eststo: xtabond turnout logportequ $controls $decades, artests(4) vce(robust) lag(1)
quietly xtabond turnout logportequ $controls $decades, artests(4) lag(1)
estat sargan
quietly eststo: xtabond turnout factor $controls $decades, artests(4) vce(robust) lag(1)
quietly xtabond turnout factor $controls $decades, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $decades, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $decades) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logtrade $controls $decades, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $decades) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $decades) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend $controls $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $decades) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $decades, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $decades) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend $controls $decades, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $decades) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $decades) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $decades) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $decades, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $decades) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controls $decades, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $decades) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls $decades) order(L.turnout $controls $decades logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls $decades) order(L.turnout $controls $decades $glob govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Use decade dummies in addition to country-specific time trends
global decades "dummy80s dummy90s dummy00s"
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div($controls $trends $decades) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div($controls $trends $decades) artests(4)
estat sargan
quietly eststo: xtabond turnout logfdistock $controls $trends $decades, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout logfdistock $controls $trends $decades, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trends $decades) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logfdiflow $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trends $decades) artests(4)
estat sargan
quietly eststo: xtabond turnout logportequ $controls $trends $decades, artests(4) vce(robust) lag(1)
quietly xtabond turnout logportequ $controls $trends $decades, artests(4) lag(1)
estat sargan
quietly eststo: xtabond turnout factor $controls $trends $decades, artests(4) vce(robust) lag(1)
quietly xtabond turnout factor $controls $trends $decades, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends $decades) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logtrade $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trends $decades) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trends $decades) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trends $decades) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends $decades) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trends $decades) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trends $decades) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trends $decades) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends $decades) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trends $decades, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trends $decades) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls $decades) order(L.turnout $controls $decades logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls $decades) order(L.turnout $controls $decades $glob govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Cubic country-specific time trends
foreach x of varlist syear2-syear920 {
  g `x'cub = `x'^3
}
global trendscubic "$trends syear2cub-syear920cub"
eststo clear
quietly eststo: xtdpd turnout L1.turnout $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div($controls $trendscubic) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div($controls $trendscubic) artests(4)
estat sargan
quietly eststo: xtabond turnout logfdistock $controls $trendscubic, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout logfdistock $controls $trendscubic, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendscubic) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logfdiflow $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logfdiflow $controls $trendscubic) artests(4)
estat sargan
quietly eststo: xtabond turnout logportequ $controls $trendscubic, artests(4) vce(robust) lag(1)
quietly xtabond turnout logportequ $controls $trendscubic, artests(4) lag(1)
estat sargan
quietly eststo: xtabond turnout factor $controls $trendscubic, artests(4) vce(robust) lag(1)
quietly xtabond turnout factor $controls $trendscubic, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logtrade $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trendscubic) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logtrade $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logtrade $controls $trendscubic) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendscubic) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend $controls $trendscubic) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trendscubic) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logportequ govspend $controls $trendscubic) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendscubic) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logfdiflow govspend logtrade $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade $controls $trendscubic) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trendscubic) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logportequ govspend logtrade $controls $trendscubic, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade $controls $trendscubic) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** OLS with country fixed effects and lagged dependent variable estimation
sort cowcode t
eststo clear
quietly eststo: xtreg turnout L1.turnout $controls $trends, fe vce(cluster cowcode)
quietly foreach `x' of varlist logfdistock logfdiflow logportequ factor logtrade {
  eststo: xtreg turnout L1.turnout `x' $controls $trends, fe vce(cluster cowcode)
}
quietly eststo: xtreg turnout L1.turnout logfdiflow govspend $controls $trends, fe vce(cluster cowcode)
quietly eststo: xtreg turnout L1.turnout logportequ govspend $controls $trends, fe vce(cluster cowcode)
quietly eststo: xtreg turnout L1.turnout logfdiflow logtrade govspend $controls $trends, fe vce(cluster cowcode)
quietly eststo: xtreg turnout L1.turnout logportequ logtrade govspend $controls $trends, fe vce(cluster cowcode)
estout, cells(b(star fmt(3)) se(par)) stats(N N_g r2_w, fmt(0 0 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g r2_w, fmt(0 0 2) labels("Observations" "Countries" "$R^2$ (within)")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** OLS with country fixed effects and panel-specifc AR1 correction (based on OLS lags and panel-specific standard errors), panel-corrected standard errors
sort cowcode t
eststo clear
quietly eststo: xtpcse turnout $controls $trends i.cowcode, correlation(psar1) pairwise
quietly foreach `x' of varlist logfdistock logfdiflow logportequ factor logtrade {
  eststo: xtpcse turnout `x' $controls $trends i.cowcode, correlation(psar1) pairwise
}
quietly eststo: xtpcse turnout logfdiflow govspend $controls $trends i.cowcode, correlation(psar1) pairwise
quietly eststo: xtpcse turnout logportequ govspend $controls $trends i.cowcode, correlation(psar1) pairwise
quietly eststo: xtpcse turnout logfdiflow logtrade govspend $controls $trends i.cowcode, correlation(psar1) pairwise
quietly eststo: xtpcse turnout logportequ logtrade govspend $controls $trends i.cowcode, correlation(psar1) pairwise
estout, cells(b(star fmt(3)) se(par)) stats(N N_g r2_w, fmt(0 0 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g r2_w, fmt(0 0 2) labels("Observations" "Countries" "$R^2$ (within)")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** System GMM estimation (using the second lag of the DV to instrument for the LDV in addition to the third and above lags)
eststo clear
quietly eststo: xtdpdsys turnout $controls $trends, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout logfdistock $controls $trends, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logfdistock syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout logfdiflow $controls $trendsminuslux, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logfdiflow syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout logportequ $controls $trends, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logportequ syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout factor $controls $trendsminuslux, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logtrade syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout logtrade $controls $trends, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logfdiflow govspend syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout logfdiflow govspend $controls $trendsminuslux, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logportequ govspend syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout logportequ govspend $controls $trends, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logfdiflow logtrade govspend syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout logfdiflow logtrade govspend $controls $trendsminuslux, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logportequ logtrade govspend syear2-syearsq920, lags(1) artests(4)
estat sargan
quietly eststo: xtdpdsys turnout logportequ logtrade govspend $controls $trends, lags(1) vce(robust) artests(4)
quietly xtdpdsys turnout logreg vap3069 timesince nopres cvfranklin mixed pr disrel enps closeness logfdiflow logtrade govspend syear2-syearsq920, lags(1) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Average globalization variables across each country's electoral cycle, i.e. the period since last election (cannot use only 3rd lag and above, so may violate AR test)
global eaglob "logeafdistock logeafdiflow logeaportequ logeatrade"
eststo clear
quietly eststo: xtabond turnout logeafdistock $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout logeafdistock $controls $trends, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logeafdiflow $controls $trendsminuslux, dgmmiv(turnout, lagrange(2)) div(logeafdiflow `var' $controls $trendsminuslux) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logeafdiflow $controls $trendsminuslux, dgmmiv(turnout, lagrange(2)) div(logeafdiflow `var' $controls $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtabond turnout logeaportequ $controls $trends, artests(4) vce(robust) lag(1)
quietly xtabond turnout logeaportequ $controls $trends, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logeatrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logeatrade `var' $controls $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logeatrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(logeatrade `var' $controls $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout logeafdiflow govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(2)) div(logeafdiflow govspend `var' $controls $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logeafdiflow govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(2)) div(logeafdiflow govspend `var' $controls $trendsminuslux) artests(4) 
estat sargan
quietly eststo: xtdpd turnout L1.turnout logeaportequ govspend $controls $trends, dgmmiv(turnout, lagrange(2)) div(logeaportequ govspend `var' $controls $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logeaportequ govspend $controls $trends, dgmmiv(turnout, lagrange(2)) div(logeaportequ govspend `var' $controls $trends) artests(4) 
estat sargan
quietly eststo: xtdpd turnout L1.turnout logeafdiflow govspend logeatrade $controls $trendsminuslux, dgmmiv(turnout, lagrange(2)) div(logeafdiflow govspend logeatrade `var' $controls $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logeafdiflow govspend logeatrade $controls $trendsminuslux, dgmmiv(turnout, lagrange(2)) div(logeafdiflow govspend logeatrade `var' $controls $trendsminuslux) artests(4) 
estat sargan
quietly eststo: xtdpd turnout L1.turnout logeaportequ govspend logeatrade $controls $trends, dgmmiv(turnout, lagrange(2)) div(logeaportequ govspend logeatrade `var' $controls $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout logeaportequ govspend logeatrade $controls $trends, dgmmiv(turnout, lagrange(2)) div(logeaportequ govspend logeatrade `var' $controls $trends) artests(4) 
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $eaglob govspend $controls) order(L.turnout $controls $eaglob govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $eaglob govspend $controls) order(L.turnout $controls $eaglob govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logeafdiflow "FDI flows (log), election average" logeafdistock "FDI stock (log), election average" logeaportequ "Portfolio stocks (log), election average" logeatrade "Trade (log), election average" govspend "Government spending")



*** Difference from election average (cannot use only 3rd lag and above, so may violate AR test)
gen cdlogfdiflow=logfdiflow-logeafdiflow
gen cdlogfdistock=logfdistock-logeafdistock
gen cdlogportequ=logportequ-logeaportequ
gen cdlogtrade=logtrade-logeatrade

global cdglob "cdlogfdistock cdlogfdiflow cdlogportequ cdlogtrade"
eststo clear
quietly eststo: xtabond turnout cdlogfdistock $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout cdlogfdistock $controls $trends, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtdpd turnout L1.turnout cdlogfdiflow $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(cdlogfdiflow `var' $controls $trendsminuslux) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout cdlogfdiflow $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(cdlogfdiflow `var' $controls $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtabond turnout cdlogportequ $controls $trends, artests(4) vce(robust) lag(1)
quietly xtabond turnout logeaportequ $controls $trends, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout cdlogtrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(cdlogtrade `var' $controls $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout logeatrade $controls $trends, dgmmiv(turnout, lagrange(3)) div(cdlogtrade `var' $controls $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout cdlogfdiflow govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(2)) div(cdlogfdiflow govspend `var' $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout cdlogportequ govspend $controls $trends, dgmmiv(turnout, lagrange(2)) div(cdlogportequ govspend `var' $controls $trends) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout cdlogfdiflow govspend cdlogtrade $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(cdlogfdiflow govspend cdlogtrade `var' $controls $trendsminuslux) artests(4) vce(robust)
quietly eststo: xtdpd turnout L1.turnout cdlogportequ govspend cdlogtrade $controls $trends, dgmmiv(turnout, lagrange(2)) div(cdlogportequ govspend cdlogtrade `var' $controls $trends) artests(4) vce(robust)
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $cdglob govspend $controls) order(L.turnout $controls $cdglob govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $cdglob govspend $controls) order(L.turnout $controls $cdglob govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" cdlogfdiflow "FDI flows (log), cycle difference" cdlogfdistock "FDI stock (log), cycle difference" cdlogportequ "Portfolio stocks (log), cycle difference" cdlogtrade "Trade (log), cycle difference" govspend "Government spending")



*** Random effects estimation, with lagged dependent variable
eststo clear
sort cowcode t
quietly eststo: xtreg turnout L1.turnout $controls $trends, vce(robust)
quietly foreach x of varlist $glob {
  eststo: xtreg turnout L1.turnout `x' $controls $trends, vce(robust)
}
quietly foreach x of varlist logfdiflow logportequ {
  eststo: xtreg turnout L1.turnout `x' govspend $controls $trends, vce(robust)
}
quietly foreach x of varlist logfdiflow logportequ {
  eststo: xtreg turnout L1.turnout `x' logtrade govspend $controls $trends, vce(robust)
}
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



**** Random coefficient estimation, with lagged dependent variable
eststo clear
quietly eststo: xtmixed turnout L1.turnout $controls $trends || cowcode: , covariance(unstructured) iterate(100) variance
foreach x of varlist $glob {
  quietly xtmixed turnout `x' L1.turnout $controls $trends || cowcode: , covariance(unstructured) iterate(100) variance
  quietly estimates store m1
  quietly eststo: xtmixed turnout `x' L1.turnout $controls $trends || cowcode: `x', covariance(unstructured) iterate(100) variance
  quietly estimates store m2
  lrtest m1 m2
}
estout, cells(b(star fmt(3)) se(par)) stats(N, fmt(0)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N, fmt(0) labels("Observations")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob $controls) order(L.turnout $controls $glob logtrade) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" factor "Ownership scale")



*** Random coefficient estimation, with common AR1
eststo clear
quietly eststo: xtmixed turnout $controls $trends || cowcode: , covariance(unstructured) residuals(ar 1, t(t)) iterate(100) variance
foreach x of varlist $glob {
  quietly xtmixed turnout `x' $controls $trends || cowcode: , covariance(unstructured) residuals(ar 1, t(t)) iterate(100) variance
  quietly estimates store m1
  quietly eststo: xtmixed turnout `x' $controls $trends || cowcode: `x', covariance(unstructured) residuals(ar 1, t(t)) iterate(100) variance
  quietly estimates store m2
  lrtest m1 m2
}
estout, cells(b(star fmt(3)) se(par)) stats(N, fmt(0)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N, fmt(0) labels("Observations")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob $controls) order(L.turnout $controls $glob logtrade) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" factor "Ownership scale")



*** Arellano and Bond models using orthogonal lags as (excluded) instruments for globalization variables
eststo clear
quietly foreach x of varlist $glob {
  eststo: xtabond turnout $controls $trends, lags(1) endog(`x') vce(robust) artests(4)
}
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")

* ...fails some tests, so use
eststo clear
foreach x of varlist $glob {
  quietly eststo: xtdpd turnout `x' L1.turnout $controls $trends, dgmmiv(turnout, lagrange(3)) dgmmiv(`x', lagrange(3)) div($controls $trends) vce(robust) artests(4)
  quietly xtdpd turnout `x' L1.turnout $controls $trends, dgmmiv(turnout, lagrange(3)) dgmmiv(`x', lagrange(3)) div($controls $trends) artests(4)
  estat sargan
}
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** 2SLS models using lagged log GDP per capita and lagged growth as (excluded) instruments for globalization variables
* eststo clear
quietly foreach x of varlist $glob {
  eststo: xtivreg turnout L1.turnout $controls $trends (`x' = L1.growth L1.loggdppc), fe first
}
estout, cells(b(star fmt(3)) se(par)) stats(N N_g widstat arm2 arm3 arm4 sargan, fmt(0 0 2 2 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "(10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade) varlabels(_cons Constant)
estout, style(tex) cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4 widstat sargan, fmt(0 0 2 2 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test" "$F$ test of excluded instruments" "Sargan $\chi^2_{(1)}$")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" nopres "US mid-term" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Include square of globalization variables instead of using logarithmic transformation
foreach x of varlist fdistock fdiflow portequ trade {
  g `x'sq = `x'^2
}
quietly eststo: xtdpd turnout L1.turnout fdiflow fdiflowsq $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(fdiflow fdiflowsq $controls $trendsminuslux) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout fdiflow fdiflowsq $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(fdiflow fdiflowsq $controls $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtabond turnout fdistock fdistocksq $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
quietly xtabond turnout fdistock fdistocksq $controls $trends, artests(4) lag(1) maxldep(9)
estat sargan
quietly eststo: xtabond turnout portequ portequsq $controls $trends, artests(4) vce(robust) lag(1)
quietly xtabond turnout portequ portequsq $controls $trends, artests(4) lag(1)
estat sargan
quietly eststo: xtdpd turnout L1.turnout trade tradesq $controls $trends, dgmmiv(turnout, lagrange(3)) div(trade tradesq $controls $trends) vce(robust) artests(4)
quietly xtdpd turnout L1.turnout trade tradesq $controls $trends, dgmmiv(turnout, lagrange(3)) div(trade tradesq $controls $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout fdiflow fdiflowsq govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(fdiflow fdiflowsq govspend $controls $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout fdiflow fdiflowsq govspend $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(fdiflow fdiflowsq govspend $controls $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout portequ portequsq govspend $controls $trends, dgmmiv(turnout, lagrange(3)) div(portequ portequsq govspend $controls $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout portequ portequsq govspend $controls $trends, dgmmiv(turnout, lagrange(3)) div(portequ portequsq govspend $controls $trends) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout fdiflow fdiflowsq govspend trade tradesq $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(fdiflow fdiflowsq govspend trade tradesq $controls $trendsminuslux) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout fdiflow fdiflowsq govspend trade tradesq $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(fdiflow fdiflowsq govspend trade tradesq $controls $trendsminuslux) artests(4)
estat sargan
quietly eststo: xtdpd turnout L1.turnout portequ portequsq govspend trade tradesq $controls $trends, dgmmiv(turnout, lagrange(3)) div(portequ portequsq govspend trade tradesq $controls $trends) artests(4) vce(robust)
quietly xtdpd turnout L1.turnout portequ portequsq govspend trade tradesq $controls $trends, dgmmiv(turnout, lagrange(3)) div(portequ portequsq govspend trade tradesq $controls $trends) artests(4)
estat sargan
estout, cells(b(star fmt(3)) se(par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2)) mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)" "(8)" "(9)" "10") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant)
estout, style(tex) cells(b(fmt(3)) se(star par)) stats(N N_g arm2 arm3 arm4, fmt(0 0 2 2 2) labels("Observations" "Countries" "AR2 test" "AR3 test" "AR4 test")) mlabels("Model (1)" "Model (2)" "Model (3)" "Model (4)" "Model (5)" "Model (6)" "Model (7)" "Model (8)" "Model (9)" "Model (10)") legend starlevels(* 0.10 ** 0.05 *** 0.01) keep(L.turnout $glob govspend $controls) order(L.turnout $controls logfdistock logfdiflow logportequ factor logtrade govspend) varlabels(_cons Constant L.turnout "LDV" logreg "Registered voters (log)" vap3069 "\%VAP,30-69" timesince "Years since last election" cvfranklin "Compulsory voting" mixed "Mixed system" pr "PR system" disrel "Disproportionality" enps "ENPS" closeness "Margin" logfdiflow "FDI flows (log)" logfdistock "FDI stock (log)" logportequ "Portfolio stocks (log)" logtrade "Trade (log)" govspend "Government spending" factor "Ownership scale")



*** Relating results to changes in the median voter
xtdpd turnout L1.turnout median $controls $trends, dgmmiv(turnout, lagrange(3)) div(median $controls $trends) vce(robust) artests(4)
xtabond turnout logfdistock median $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
xtdpd turnout L1.turnout logfdiflow median $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow median $controls $trendsminuslux) vce(robust) artests(4)
xtabond turnout logportequ median $controls $trends, artests(4) vce(robust) lag(1)
xtabond turnout factor median $controls $trendsminuslux, artests(4) vce(robust) lag(1)
xtdpd turnout L1.turnout logtrade median $controls $trends, dgmmiv(turnout, lagrange(3)) div(logtrade median $controls $trends) vce(robust) artests(4)
xtdpd turnout L1.turnout logfdiflow govspend median $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend median $controls $trendsminuslux) artests(4) vce(robust)
xtdpd turnout L1.turnout logportequ govspend median $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend median $controls $trends) artests(4) vce(robust)
xtdpd turnout L1.turnout logfdiflow govspend logtrade median $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow govspend logtrade median $controls $trendsminuslux) artests(4) vce(robust)
xtdpd turnout L1.turnout logportequ govspend logtrade median $controls $trends, dgmmiv(turnout, lagrange(3)) div(logportequ govspend logtrade median $controls $trends) artests(4) vce(robust)

foreach x of varlist logfdiflow logfdistock logportequ factor logtrade {
  g `x'median = median * `x'
}
xtabond turnout logfdistock logfdistockmedian median $controls $trends, vce(robust) artests(4) lag(1) maxldep(9)
xtdpd turnout L1.turnout logfdiflow logfdiflowmedian median logfdiflowmedian $controls $trendsminuslux, dgmmiv(turnout, lagrange(3)) div(logfdiflow logfdiflowmedian median $controls $trendsminuslux) vce(robust) artests(4)
xtabond turnout logportequ logportequmedian median $controls $trends, artests(4) vce(robust) lag(1)
xtabond turnout factor factormedian median $controls $trendsminuslux, artests(4) vce(robust) lag(1)
xtdpd turnout L1.turnout logtrade logtrademedian median $controls $trends, dgmmiv(turnout, lagrange(3)) div(logtrade logtrademedian median $controls $trends) vce(robust) artests(4)
